@@ -1,10 +1,10 @@
-LIMIT_1 = 1
+from sqlexecutorx.constant import LIMIT_1, CACHE_SIZE
 
-CACHE_SIZE = 256
+MODULE = 'SQLExecX'
 
 SELECT_COUNT = 'count(1)'
 
-NAMED_REGEX = r':[\w|\d]*'
+NAMED_REGEX = r':[a-z|A-Z|\d][\w|\d]*'
 
 DEFAULT_KEY_FIELD = 'id'
 
