@@ -1,11 +1,11 @@
-from sqlexecutorx import DBError
-from typing import Collection, Iterable, List, Tuple
+from typing import Collection, Iterable, List, Tuple, Mapping
 from .loader import Loader
 from .dialect import Dialect
 from . import sql_support
-from .log_support import logger, insert_log, save_log
+from .constant import MODULE
+from .log_support import logger, insert_log, save_log, batch_sql_log
 from sqlexecutorx import execute as _execute, select as _select, select_one as _select_one, do_select as _do_select,\
-    save as _save, batch_execute as _batch_execute, get as _get, query as _query, query_one as _query_one
+    save as _save, batch_execute as _batch_execute, get as _get, query as _query, query_one as _query_one, DBError
 
 
 def execute(sql: str, *args, **kwargs) -> int:
@@ -44,7 +44,7 @@ def insert(table_name: str, **kwargs) -> int:
 
     insert_log('insert', table_name, **kwargs)
     sql, args = sql_support.insert_sql_args(table_name.strip(), **kwargs)
-    return do_execute(sql, *args)
+    return _execute(sql, *args)
 
 
 def save(table_name: str, **kwargs):
@@ -467,8 +467,10 @@ def batch_execute(sql: str, *args) -> int:
     2
     """
 
+    batch_sql_log(MODULE, 'batch_execute', sql, args)
     assert args, "*args must not be empty."
-    if isinstance(args[0], dict):
+    args = sql_support.get_batch_args(*args)
+    if isinstance(args[0], Mapping):
         sql, args = sql_support.batch_named_sql_args(sql, *args)
     sql = Dialect.before_execute(sql)
     args = sql_support.get_batch_args(*args)
@@ -487,12 +489,18 @@ def batch_insert(table_name: str, *args) -> int:
     --------
     >>> import sqlexecx as db
     >>> args =  [{'name': '张三', 'age': 20}, {'name': '李四', 'age': 28}]
+    >>> db.batch_execute('person', args)
+    2
     >>> db.batch_execute('person', *args)
     2
     """
+    
     logger.debug("Exec func 'sqlexecx.%s' \n\t Table: '%s', args: %s" % ('batch_insert', table_name, args))
+    assert args, "*args must not be empty."
+    args = sql_support.get_batch_args(*args)
+    assert isinstance(args[0], Mapping), 'args must be a collection of Mapping'
     sql, args = sql_support.batch_insert_sql_args(table_name, *args)
-    return batch_execute(sql, *args)
+    return _batch_execute(sql, *args)
 
 
 def load(sql: str, *args, **kwargs) -> Loader:
