@@ -2,10 +2,12 @@
 # -*- coding:utf-8 -*-
 
 from typing import List, Tuple
+from functools import lru_cache
 
 from . import exec
 from .loader import Loader
 from .page_exec import PageExec
+from .constant import CACHE_SIZE
 
 
 class SqlPageExec:
@@ -570,6 +572,7 @@ class SqlExec:
         return SqlPageExec(self.sql, PageExec(self.exec, page_num=page_num, page_size=page_size))
 
 
+@lru_cache(maxsize=CACHE_SIZE)
 def sql(sql_text: str) -> SqlExec:
     """
     Get a SqlExec instance
