@@ -1,142 +1,17 @@
 # !/usr/bin/env python3
 # -*- coding:utf-8 -*-
 
-from typing import Sequence, Tuple, List, Union
+from functools import lru_cache
+from typing import Tuple, List, Union
+from sqlexecutorx import batch_execute as _batch_execute
 from .loader import Loader
 from . import exec, sql_support
 from .dialect import Dialect, Engine
-from .constant import LIMIT_1, SELECT_COUNT
-from .sql_support import get_table_select_sql
-
-
-class TablePageExec:
-
-    def __init__(self, table_exec, page_num, page_size):
-        self.table_exec = table_exec
-        self.page_num = page_num
-        self.page_size = page_size
-
-    def select(self, *columns) -> List[Tuple]:
-        """
-        Select data from table and return list results(dict).
-
-        Examples
-        --------
-        >>> import sqlexecx as db
-        >>> db.table('person').page(1, 10).select('id', 'name', 'age')
-        [(3, '张三', 20)]
-        """
-        sql = get_table_select_sql(self.table_exec.table, '', 0, *columns)
-        return self.table_exec.exec.do_select_page(sql, self.page_num, self.page_size)
-
-    def query(self, *columns) -> List[dict]:
-        """
-        Select data from table and return list results(dict).
-
-        Examples
-        --------
-        >>> import sqlexecx as db
-        >>> db.table('person').page(1, 10).query('id', 'name', 'age')
-        [{'id': 3, 'name': '张三', 'age': 20}]
-        """
-        sql = get_table_select_sql(self.table_exec.table, '', 0, *columns)
-        return self.table_exec.exec.do_query_page(sql, self.page_num, self.page_size)
-
-
-class ColumnPageExec:
-
-    def __init__(self, table_page_exec: TablePageExec, *columns):
-        self.table_page_exec = table_page_exec
-        self.columns = columns
-
-    def select(self) -> List[Tuple]:
-        """
-        Select data from table and return list results(tuple).
-
-        Examples
-        --------
-        >>> import sqlexecx as db
-        >>> db.table('person').columns('id', 'name', 'age').page(1, 10).select()
-        [(3, '张三', 20)]
-        """
-        return self.table_page_exec.select(*self.columns)
-
-    def query(self) -> List[dict]:
-        """
-        Select data from table and return list results(dict).
-
-        Examples
-        --------
-        >>> import sqlexecx as db
-        >>> db.table('person').columns('id', 'name', 'age').page(1, 10).query()
-        [{'id': 3, 'name': '张三', 'age': 20}]
-        """
-        return self.table_page_exec.query(*self.columns)
-
-
-class WherePageExec:
-
-    def __init__(self, where_exec, page_num, page_size):
-        self.where_exec = where_exec
-        self.page_num = page_num
-        self.page_size = page_size
-
-    def select(self, *columns) -> List[Tuple]:
-        """
-        Select data from table and return list results(tuple).
-
-        Examples
-        --------
-        >>> import sqlexecx as db
-        >>> db.table('person').where(name='张三', age=20).page(1, 10).select('id', 'name', 'age')
-        [(3, '张三', 20)]
-        """
-        sql, args = self.where_exec.get_select_sql_args(*columns)
-        return self.where_exec.exec.do_select_page(sql, self.page_num, self.page_size, *args)
-
-    def query(self, *columns) -> List[dict]:
-        """
-        Select data from table and return list results(dict).
-
-        Examples
-        --------
-        >>> import sqlexecx as db
-        >>> db.table('person').where(name='张三', age=20).page(1, 10).query('id', 'name', 'age')
-        [{'id': 3, 'name': '张三', 'age': 20}]
-        """
-        sql, args = self.where_exec.get_select_sql_args(*columns)
-        return self.where_exec.exec.do_query_page(sql, self.page_num, self.page_size, *args)
-
-
-class ColumnWherePageExec:
-
-    def __init__(self, where_page_exec: WherePageExec, *columns):
-        self.where_page_exec = where_page_exec
-        self.columns = columns
-
-    def select(self) -> List[Tuple]:
-        """
-        Select data from table and return list results(tuple).
-
-        Examples
-        --------
-        >>> import sqlexecx as db
-        >>> db.table('person').columns('id', 'name', 'age').where(name='张三', age=20).page(1, 10).select()
-        [(3, '张三', 20)]
-        """
-        return self.where_page_exec.select(*self.columns)
-
-    def query(self) -> List[dict]:
-        """
-        Select data from table and return list results(dict).
-
-        Examples
-        --------
-        >>> import sqlexecx as db
-        >>> db.table('person').columns('id', 'name', 'age').where(name='张三', age=20).page(1, 10).query()
-        [{'id': 3, 'name': '张三', 'age': 20}]
-        """
-        return self.where_page_exec.query(*self.columns)
+from .constant import LIMIT_1, SELECT_COUNT, CACHE_SIZE
+from .table_support import get_table_select_sql, get_where_arg_limit, WhereBase
+from .table_limit_exec import LimitExec, ColumnLimitExec, WhereLimitExec, ColumnWhereLimitExec
+from .table_page_exec import TablePageExec, ColumnPageExec, WherePageExec, ColumnWherePageExec
+from .table_order_by import OrderByExec, ColumnOrderByExec, WhereOrderByExec, ColumnWhereOrderByExec
 
 
 class ColumnWhereExec:
@@ -209,7 +84,7 @@ class ColumnWhereExec:
         Examples
         --------
         >>> import sqlexecx as db
-        >>> db..table('person').columns('id', 'name', 'age').where(name__eq='李四').to_df()
+        >>> db.table('person').columns('id', 'name', 'age').where(name__eq='李四').to_df()
         """
         return self._where_exec.load(*self.columns).to_df()
 
@@ -235,7 +110,7 @@ class ColumnWhereExec:
         """
         self._where_exec.load(*self.columns).to_json(file_name, encoding)
 
-    def page(self, page_num=1, page_size=10) -> ColumnWherePageExec:
+    def page(self, page_num=1, page_size=10, return_total=False) -> ColumnWherePageExec:
         """
         Get a ColumnWherePageExec instance
 
@@ -245,15 +120,37 @@ class ColumnWhereExec:
         >>> db.table('person').columns('id', 'name', 'age').where(name='张三', age=20).page(1, 10)
         ColumnWherePageExec()
         """
-        return ColumnWherePageExec(WherePageExec(self._where_exec, page_num, page_size), *self.columns)
+        return ColumnWherePageExec(self._where_exec.page(page_num, page_size, return_total), *self.columns)
+
+    def limit(self, limit: Union[int, Tuple[int], List[int]] = 10) -> ColumnWhereLimitExec:
+        """
+        Get a ColumnWhereLimitExec instance
+
+        Examples
+        --------
+        >>> import sqlexecx as db
+        >>> db.table('person').columns('id', 'name', 'age').where(name='张三', age=20).limit(10)
+        ColumnWhereLimitExec()
+        """
+        return ColumnWhereLimitExec(self._where_exec.limit(limit), *self.columns)
+    
+    def order_by(self, order_by: str) -> ColumnWhereOrderByExec:
+        """
+        Get a ColumnWhereOrderByExec instance
+
+        Examples
+        --------
+        >>> import sqlexecx as db
+        >>> db.table('person').columns('id', 'name', 'age').where(name='张三', age=20).order_by('id DESC, name ASC')
+        ColumnWhereOrderByExec()
+        """
+        return ColumnWhereOrderByExec(self._where_exec.order_by(order_by), *self.columns)
 
 
-class WhereExec:
+class WhereExec(WhereBase):
 
-    def __init__(self, _exec, table_name, **kwargs):
-        self.exec = _exec
-        self.table = table_name
-        self.where_condition = kwargs
+    def __init__(self, _exec, table_name: str, order_by: str, **kwargs):
+        super().__init__(_exec, table_name, order_by, **kwargs)
 
     def get(self, column: str):
         """
@@ -290,19 +187,6 @@ class WhereExec:
         """
         return self.get(1) == 1
 
-    def select(self, *columns) -> List[Tuple]:
-        """
-        Select data from table and return list results(tuple).
-
-        Examples
-        --------
-        >>> import sqlexecx as db
-        >>> db.table('person').where(name='张三', age=20).select('id', 'name', 'age')
-        [(3, '张三', 20)]
-        """
-        sql, args = self.get_select_sql_args(*columns)
-        return self.exec.do_select(sql, *args)
-
     def select_one(self, *columns) -> Tuple:
         """
         Select data from table and return list results(dict).
@@ -316,19 +200,6 @@ class WhereExec:
         sql, args = self.get_select_one_sql_args(*columns)
         return self.exec.do_select_one(sql, *args, LIMIT_1)
 
-    def query(self, *columns) -> List[dict]:
-        """
-        Select data from table and return list results(tuple).
-
-        Examples
-        --------
-        >>> import sqlexecx as db
-        >>> db.table('person').where(name='张三', age=20).query('id', 'name', 'age')
-        [{'id': 3, 'name': '张三', 'age': 20}]
-        """
-        sql, args = self.get_select_sql_args(*columns)
-        return self.exec.do_query(sql, *args)
-
     def query_one(self, *columns) -> dict:
         """
         Select from table and return unique result(dict), SQL contain 'limit'.
@@ -354,7 +225,7 @@ class WhereExec:
         """
         where, args, _ = get_where_arg_limit(**self.where_condition)
         sql = 'DELETE FROM %s %s' % (Dialect.get_dialect_str(self.table), where)
-        if Dialect.curr_engine() in (Engine.MYSQL, Engine.SQLITE):
+        if Dialect.curr_engine() == Engine.MYSQL:
             sql = '{} LIMIT ?'.format(sql)
             args = [*args, LIMIT_1]
         return self.exec.do_execute(sql, *args)
@@ -374,24 +245,11 @@ class WhereExec:
         args = [*update_args, *args]
         update_cols = ', '.join(['{} = ?'.format(Dialect.get_dialect_str(col)) for col in update_cols])
         sql = 'UPDATE {} SET {} {}'.format(Dialect.get_dialect_str(self.table), update_cols, where)
-        if Dialect.curr_engine() in (Engine.MYSQL, Engine.SQLITE):
+        if Dialect.curr_engine() == Engine.MYSQL:
             sql = '{} LIMIT ?'.format(sql)
             args = [*args, LIMIT_1]
         return self.exec.do_execute(sql, *args)
 
-    def load(self, *columns) -> Loader:
-        """
-        Get a Loader instance
-
-        Examples
-        --------
-        >>> import sqlexecx as db
-        >>> db.table('person').where(name='张三', age=20).load('id', 'name', 'age')
-        Loader()
-        """
-        sql, args = self.get_select_sql_args(*columns)
-        return self.exec.do_load(sql, *args)
-
     def columns(self, *columns) -> ColumnWhereExec:
         """
         Get a ColumnWhereExec instance
@@ -404,7 +262,7 @@ class WhereExec:
         """
         return ColumnWhereExec(self, *columns)
 
-    def page(self, page_num=1, page_size=10) -> WherePageExec:
+    def page(self, page_num=1, page_size=10, return_total=False) -> WherePageExec:
         """
         Get a WherePageExec instance
 
@@ -414,92 +272,33 @@ class WhereExec:
         >>> db.table('person').where(name='张三', age=20).page(1, 10)
         WherePageExec()
         """
-        return WherePageExec(self, page_num, page_size)
+        return WherePageExec(self, page_num, page_size, return_total)
 
-    def get_select_sql_args(self, *columns):
-        where, args, limit = get_where_arg_limit(**self.where_condition)
-        sql = get_table_select_sql(self.table, where, limit, *columns)
-        if limit:
-            if isinstance(limit, int):
-                args = [*args, limit]
-            else:
-                args = [*args, *limit]
-        return sql, args
-
-    def get_select_one_sql_args(self, *columns):
-        where, args, _ = get_where_arg_limit(**self.where_condition)
-        sql = get_table_select_sql(self.table, where, LIMIT_1, *columns)
-        return sql, args
-
-
-class LimitExec:
-
-    def __init__(self, _exec, table_name: str, limit: Union[int, Tuple[int], List[int]]):
-        self.exec = _exec
-        self.table = table_name
-        self.limit = limit
-
-    def select(self, *columns) -> List[Tuple]:
+    def limit(self, limit: Union[int, Tuple[int], List[int]] = 10) -> WhereLimitExec:
         """
-        Select data from table and return list results(tuple).
+        Get a WhereLimitExec instance
 
         Examples
         --------
         >>> import sqlexecx as db
-        >>> db.table('person').limit(10).select('id', 'name', 'age')
-        [(3, '张三', 20)]
+        >>> db.table('person').where(name='张三', age=20).limit(10)
+        WhereLimitExec()
         """
-        sql = get_table_select_sql(self.table, '', self.limit, *columns)
-        return self.exec.do_select(sql, self.limit)
-
-    def query(self, *columns) -> List[Tuple]:
+        return WhereLimitExec(self.exec, self.table, None, limit, **self.where_condition)
+    
+    def order_by(self, order_by: str) -> WhereOrderByExec:
         """
-        Select data from table and return list results(dict).
+        Get a WhereOrderByExec instance
 
         Examples
         --------
         >>> import sqlexecx as db
-        >>> db.table('person').limit(10).query('id', 'name', 'age')
-        [{'id': 3, 'name': '张三', 'age': 20}]
+        >>> db.table('person').columns('id', 'name', 'age').order_by('id DESC, name ASC')
+        WhereOrderByExec()
         """
-        sql = get_table_select_sql(self.table, '', self.limit, *columns)
-        if isinstance(self.limit, int):
-            return self.exec.do_query(sql, self.limit)
-        else:
-            return self.exec.do_query(sql, *self.limit)
-
-
-class ColumnLimitExec:
-
-    def __init__(self, limit_exec: LimitExec, *columns):
-        self.limit_exec = limit_exec
-        self.columns = columns
-
-    def select(self) -> List[Tuple]:
-        """
-        Select data from table and return list results(tuple).
-
-        Examples
-        --------
-        >>> import sqlexecx as db
-        >>> db.table('person').columns('id', 'name', 'age').limit(10).select()
-        [(3, '张三', 20)]
-        """
-        return self.limit_exec.select(*self.columns)
-
-    def query(self) -> List[Tuple]:
-        """
-        Select data from table and return list results(dict).
-
-        Examples
-        --------
-        >>> import sqlexecx as db
-        >>> db.table('person').columns('id', 'name', 'age').limit(10).query()
-        [{'id': 3, 'name': '张三', 'age': 20}]
-        """
-        return self.limit_exec.query(*self.columns)
-
-
+        return WhereOrderByExec(self.exec, self.table, order_by, **self.where_condition)
+    
+  
 class ColumnExec:
 
     def __init__(self, table_exec, *columns):
@@ -520,7 +319,7 @@ class ColumnExec:
         sql = sql_support.insert_sql(self.table_exec.table.strip(), self.columns)
         return self.table_exec.exec.execute(sql, *args)
 
-    def batch_insert(self, args: Union[List[Tuple], List[List], Tuple[Tuple], Tuple[List]]) -> int:
+    def batch_insert(self, *args) -> int:
         """
         Batch insert data into table and return effect rowcount
 
@@ -528,11 +327,13 @@ class ColumnExec:
         --------
         >>> import sqlexecx as db
         >>> args = [('张三', 20), ('李四', 28)]
+        >>> db.table('person').columns('name', 'age').batch_insert(args)
+        2
         >>> db.table('person').columns('name', 'age').batch_insert(*args)
         2
         """
         sql = sql_support.insert_sql(self.table_exec.table.strip(), self.columns)
-        return self.table_exec.exec.batch_execute(sql, *args)
+        return _batch_execute(sql, *args)
 
     def get(self):
         """
@@ -603,7 +404,7 @@ class ColumnExec:
         Examples
         --------
         >>> import sqlexecx as db
-        >>> db..table('person').columns('id', 'name', 'age').to_df()
+        >>> db.table('person').columns('id', 'name', 'age').to_df()
         """
         return self.table_exec.load(*self.columns).to_df()
 
@@ -641,7 +442,7 @@ class ColumnExec:
         """
         return ColumnWhereExec(self.table_exec.where(**kwargs), *self.columns)
 
-    def page(self, page_num=1, page_size=10) -> ColumnPageExec:
+    def page(self, page_num=1, page_size=10, return_total=False) -> ColumnPageExec:
         """
         Get a ColumnPageExec instance
 
@@ -651,7 +452,7 @@ class ColumnExec:
         >>> db.table('person').columns('id', 'name', 'age').page(1, 10)
         ColumnPageExec()
         """
-        return ColumnPageExec(TablePageExec(self.table_exec, page_num, page_size), *self.columns)
+        return ColumnPageExec(self.table_exec.page(page_num, page_size, return_total), *self.columns)
 
     def limit(self, limit: Union[int, Tuple[int], List[int]] = 10) -> ColumnLimitExec:
         """
@@ -660,10 +461,22 @@ class ColumnExec:
         Examples
         --------
         >>> import sqlexecx as db
-        >>> db.table('person').limit(10)
+        >>> db.table('person').columns('id', 'name', 'age').limit(10)
         ColumnLimitExec()
         """
         return ColumnLimitExec(self.table_exec.limit(limit), *self.columns)
+    
+    def order_by(self, order_by: str) -> ColumnOrderByExec:
+        """
+        Get a ColumnOrderByExec instance
+
+        Examples
+        --------
+        >>> import sqlexecx as db
+        >>> db.table('person').columns('id', 'name', 'age').order_by('id DESC, name ASC')
+        ColumnOrderByExec()
+        """
+        return ColumnOrderByExec(self.table_exec.order_by(order_by), *self.columns)
 
 
 class TableExec:
@@ -739,7 +552,7 @@ class TableExec:
         >>> db.table('person').get('count(1)')
         3
         """
-        sql = get_table_select_sql(self.table, '', LIMIT_1, column)
+        sql = get_table_select_sql(self.table, None, None, LIMIT_1, column)
         return self.exec.do_get(sql, LIMIT_1)
 
     def count(self) -> int:
@@ -762,7 +575,7 @@ class TableExec:
         >>> db.table('person').select('id', 'name', 'age')
         [(3, '张三', 20)]
         """
-        sql = get_table_select_sql(self.table, '', 0, *columns)
+        sql = get_table_select_sql(self.table, None, None, 0, *columns)
         return self.exec.do_select(sql)
 
     def select_one(self, *columns) -> Tuple:
@@ -775,7 +588,7 @@ class TableExec:
         >>> db.table('person').do_select_one('id', 'name', 'age')
         (3, '张三', 20)
         """
-        sql = get_table_select_sql(self.table, '', LIMIT_1, *columns)
+        sql = get_table_select_sql(self.table, None, None, LIMIT_1, *columns)
         return self.exec.do_select_one(sql, LIMIT_1)
 
     def query(self, *columns) -> List[dict]:
@@ -788,7 +601,7 @@ class TableExec:
         >>> db.table('person').query('id', 'name', 'age')
         [{'id': 3, 'name': '张三', 'age': 20}]
         """
-        sql = get_table_select_sql(self.table, '', 0, *columns)
+        sql = get_table_select_sql(self.table, None, None, 0, *columns)
         return self.exec.do_query(sql)
 
     def query_one(self, *columns) -> dict:
@@ -801,7 +614,7 @@ class TableExec:
         >>> db.table('person').query_one('id', 'name', 'age')
         {'id': 3, 'name': '张三', 'age': 20}
         """
-        sql = get_table_select_sql(self.table, '', LIMIT_1, *columns)
+        sql = get_table_select_sql(self.table, None, None, LIMIT_1, *columns)
         return self.exec.do_query_one(sql, LIMIT_1)
 
     def load(self, *columns) -> Loader:
@@ -816,7 +629,7 @@ class TableExec:
         >>> db.table('person').load('id', 'name', 'age')
         Lodder()
         """
-        sql = get_table_select_sql(self.table, '', 0, *columns)
+        sql = get_table_select_sql(self.table, None, None, 0, *columns)
         return self.exec.do_load(sql)
 
     def insert_from_df(self, df, columns: Tuple[str] = None):
@@ -889,7 +702,7 @@ class TableExec:
         >>> db.table('person').where(name='张三', age=20)
         WhereExec()
         """
-        return WhereExec(self.exec, self.table, **kwargs)
+        return WhereExec(self.exec, self.table, None, **kwargs)
 
     def columns(self, *columns) -> ColumnExec:
         """
@@ -903,7 +716,7 @@ class TableExec:
         """
         return ColumnExec(self, *columns)
 
-    def page(self, page_num=1, page_size=10) -> TablePageExec:
+    def page(self, page_num=1, page_size=10, return_total=False) -> TablePageExec:
         """
         Get a TablePageExec instance
 
@@ -913,7 +726,7 @@ class TableExec:
         >>> db.table('person').page(1, 10)
         TablePageExec()
         """
-        return TablePageExec(self,  page_num, page_size)
+        return TablePageExec(self, page_num, page_size, return_total)
 
     def limit(self, limit: Union[int, Tuple[int], List[int]] = 10) -> LimitExec:
         """
@@ -925,9 +738,22 @@ class TableExec:
         >>> db.table('person').limit(10)
         LimitExec()
         """
-        return LimitExec(self.exec, self.table, limit)
+        return LimitExec(self.exec, self.table, None, limit)
+    
+    def order_by(self, order_by: str) -> OrderByExec:
+        """
+        Get a OrderByExec instance
+
+        Examples
+        --------
+        >>> import sqlexecx as db
+        >>> db.table('person').order_by('id DESC, name ASC')
+        OrderByExec()
+        """
+        return OrderByExec(self.exec, self.table, order_by)
 
 
+@lru_cache(maxsize=CACHE_SIZE)
 def table(table_name: str) -> TableExec:
     """
     Get a TableExec instance
@@ -940,69 +766,3 @@ def table(table_name: str) -> TableExec:
     table_name = table_name.strip()
     assert table_name, "Parameter 'table' must not be none"
     return TableExec(exec, table_name)
-
-
-def get_condition_arg(k: str, v: object):
-    if k.endswith("__eq"):
-        return "{} = ?".format(Dialect.get_dialect_str(k[:-4])), v
-    if k.endswith("__ne"):
-        return "{} != ?".format(Dialect.get_dialect_str(k[:-4])), v
-    if k.endswith("__gt"):
-        return "{} > ?".format(Dialect.get_dialect_str(k[:-4])), v
-    if k.endswith("__lt"):
-        return "{} < ?".format(Dialect.get_dialect_str(k[:-4])), v
-    if k.endswith("__ge"):
-        return "{} >= ?".format(Dialect.get_dialect_str(k[:-4])), v
-    if k.endswith("__gte"):
-        return "{} >= ?".format(Dialect.get_dialect_str(k[:-5])), v
-    if k.endswith("__le"):
-        return "{} <= ?".format(Dialect.get_dialect_str(k[:-4])), v
-    if k.endswith("__lte"):
-        return "{} <= ?".format(Dialect.get_dialect_str(k[:-5])), v
-    if k.endswith("__isnull"):
-        return "{} is {}".format(Dialect.get_dialect_str(k[:-8]), 'null' if v else 'not null'), None
-    if k.endswith("__in") and isinstance(v, Sequence) and not isinstance(v, str):
-        return "{} in({})".format(Dialect.get_dialect_str(k[:-4]), ','.join(['?' for _ in v])), v
-    if k.endswith("__in"):
-        return "{} in({})".format(Dialect.get_dialect_str(k[:-4]), '?'), v
-    if k.endswith("__not_in") and isinstance(v, Sequence) and not isinstance(v, str):
-        return "{} not in({})".format(Dialect.get_dialect_str(k[:-8]), ','.join(['?' for _ in v])), v
-    if k.endswith("__not_in"):
-        return "{} not in({})".format(Dialect.get_dialect_str(k[:-8]), '?'), v
-    if k.endswith("__like"):
-        return "{} like ?".format(Dialect.get_dialect_str(k[:-6])), '%{}%'.format(v)
-    if k.endswith("__startswith"):
-        return "{} like ?".format(Dialect.get_dialect_str(k[:-12])), '{}%'.format(v)
-    if k.endswith("__endswith"):
-        return "{} like ?".format(Dialect.get_dialect_str(k[:-10])), '%{}'.format(v)
-    if k.endswith("__contains"):
-        return "{} like ?".format(Dialect.get_dialect_str(k[:-10])), '%{}%'.format(v)
-    if k.endswith("__range") and isinstance(v, Sequence) and 2 == len(v) and not isinstance(v, str):
-        col = k[:-7]
-        return "{} >= ? and {} <= ?".format(Dialect.get_dialect_str(col), Dialect.get_dialect_str(col)), v
-    if k.endswith("__between") and isinstance(v, Sequence) and 2 == len(v) and not isinstance(v, str):
-        return "{} between ? and ?".format(Dialect.get_dialect_str(k[:-9])), v
-    if k.endswith("__range") or k.endswith("__between"):
-        return ValueError("Must is instance of Sequence with length 2 when use range or between statement")
-
-    return "{} = ?".format(Dialect.get_dialect_str(k)), v
-
-
-def get_where_arg_limit(**kwargs):
-    where, args, limit = '', [], 0
-    if 'limit' in kwargs:
-        limit = kwargs.pop('limit')
-
-    if kwargs:
-        conditions, tmp_args = zip(*[get_condition_arg(k, v) for k, v in kwargs.items()])
-        tmp_args = [arg for arg in tmp_args if arg is not None]
-
-        for arg in tmp_args:
-            if arg is not None:
-                if isinstance(arg, Sequence) and not isinstance(arg, str):
-                    args.extend(arg)
-                else:
-                    args.append(arg)
-        where = 'WHERE {}'.format(' and '.join(conditions))
-
-    return where, args, limit
